@@ -106,19 +106,19 @@ lab_sum <- function(feature, data, whole_text = TRUE, transform_feature = TRUE)
 ## @param feature character string representing the feature for which we want to generate an icon
 create_icon <- function(feature) {
     icon <- switch(feature,
-                   "distance" = "area-chart",
-                   "duration" = "clock-o",
-                   "avgSpeed" = "line-chart",
-                   "avgAltitude" = "arrows-v",
-                   "total_elevation_gain" = "arrows-v",
-                   "avgTemperature" = "thermometer",
+                   "distance" = "chart-area",
+                   "duration" = "clock",
+                   "avgSpeed" = "chart-line",
+                   "avgAltitude" = "arrows-alt-v",
+                   "total_elevation_gain" = "arrows-alt-v",
+                   "avgTemperature" = "thermometer-half",
                    "nsessions_cycling" = "bicycle",
                    "nsessions_running" = "walking",
                    "nsessions_swimming" = "swimmer",
-                   "avgPace" = "tachometer",
-                   "avgCadenceRunning" = "tachometer",
-                   "avgCadenceCycling" = "tachometer",
-                   "avgPower" = "flash",
+                   "avgPace" = "tachometer-alt",
+                   "avgCadenceRunning" = "tachometer-alt",
+                   "avgCadenceCycling" = "tachometer-alt",
+                   "avgPower" = "bolt",
                    "avgHeartRate" = "heartbeat",
                    "wrRatio" = "fire")
     icon
